import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import {
  select,
  axisLeft,
  axisBottom,
  csv,
  arc,
  pie,
  scaleBand,
  scaleLinear,
  max,
} from 'd3'; // added d3 import and fixed typo in axisLeft

const csvUrl =
  'https://gist.githubusercontent.com/snehareddygurram/59dc3a5d023d7349cd16fd80abade3e0/raw/11a8b8628c742397547ab8c7d5b055820f0d3898/selected%2520service.csv';
const width = 960;
const height = 500;
const margin = { top: 20, right: 20, bottom: 50, left: 200 };

const App = () => {
  const [data, setData] = useState(null);
  useEffect(() => {
    const row = (d) => {
      d.basic_cost = +d['basic_cost'];
      return d;
    };
    csv(csvUrl, row).then((data) => {
      setData(data.slice(0, 15));
    });
  }, []); // added missing closing parenthesis

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom - 100;
  const innerWidth = width - margin.left - margin.right; // fixed typo in innerWidth

  const yScale = scaleBand()
    .domain(data.map((d) => d.country))
    .range([0, innerHeight]);
  const xScale = scaleLinear()
    .domain([0, max(data, (d) => d.basic_cost)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        {/* fixed backticks and added missing closing parenthesis */}
        {xScale.ticks().map((tickValue) => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            {/* fixed backticks */}
            <line y2={innerHeight} stroke="blue" />
            <text style={{ textAnchor: 'middle' }} dy=".70em" y={innerHeight + 3}>
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map((tickValue) => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map((d) => (
          <rect // fixed typo in rect
            key={d.country} // fixed extra closing parenthesis
            x={0}
            y={yScale(d.country)}
            width={xScale(d.basic_cost)}
            height={yScale.bandwidth()}
          />
        ))}
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);



